/*!
 * @file network_monitor.h
 *  a class to monitor the network: throughput, network nodes
 */

#ifndef _NETWORK_MONITOR_H
#define _NETWORK_MONITOR_H

#include "base_object.h"
#include "synchronizeable.h"

#include <list>

class NetworkStream;
class PeerInfo;

namespace OrxGui { class GLGuiBox; };

//!< a class representing a node in the network (this can be a MASTER_SERVER, PROXY_SERVER or a CLIENT
class NetworkNode
{
  public:
    NetworkNode() {}
    ~NetworkNode() {}


  private:
    int                          nodeType;                     //!< the type of the node

    std::list<PeerInfo*>         clientList;                   //!< list of all clients in the network
    std::list<PeerInfo*>         proxyServerList;              //!< list of all proxy servers in the network
    std::list<PeerInfo*>         masterServerList;             //!< list of all master servers in the network (should be 1!! :D)

};

//!< a class that monitors the whole network. it tries to gather all informations its able to from the network
class NetworkMonitor : public Synchronizeable
{

  public:
    NetworkMonitor(NetworkStream* networkStream);
    virtual ~NetworkMonitor();


    void addClient(PeerInfo* node);
    void addProxyServer(PeerInfo* node);
    void addMasterServer(PeerInfo* node);

    void removeClient(PeerInfo* node);
    void removeProxyServer(PeerInfo* node);
    void removeMasterServer(PeerInfo* node);

    void showGUI();
    void hideGUI();

    void process();


  private:
    std::list<PeerInfo*>         clientList;                   //!< list of all clients in the network
    std::list<PeerInfo*>         proxyServerList;              //!< list of all proxy servers in the network
    std::list<PeerInfo*>         masterServerList;             //!< list of all master servers in the network (should be 1!! :D)


    OrxGui::GLGuiBox*            box;

    int                          playerNumber;                 //!< total number of players in the game
};


#endif
